function ape = moist_mape_ipcc(pfull, lat, temp_avg, rhum_avg, ps, min_lat, max_lat, do_dry, do_nonconvective)

%  Example of how to calculate mean ape (MAPE) of a moist atmosphere that varies with pressure and latitude (was applied to IPCC model output)
%  Result is expressed in J/m^2

  error(nargchk(9, 9, nargin))

  % pfull: pressure (Pa); first element is highest pressure
  % lat: latitude (degrees)
  % temp_avg: mean temperature versus pressure and latitude (K)
  % rhum_avg: mean relative humidity versus pressure and latitude (fraction rather than percent)
  % ps: surface pressure versus latitude (Pa)
  % min_lat: minimum latitude (degrees)
  % max_lat: maximum latitude (degrees)
  % do_dry: ignore moisture
  % do_nonconvective: "non-convective" moist ape discussed in O'Gorman, PNAS, 2010 that does not allow the reordering of the pressure of air parcels originating at a given latitude


  if do_dry
   rhum_avg = zeros(size(rhum_avg));  % has to be all zeros (no NaNs)
  end

  % interpolate to common grid with even spacing
  % and unique pressure levels (See Lorenz paper)
  num_lev = 40;
  num_lat = 40;
  pA = 0.05e5; 
  pB = 1.0e5;

  % exclude subsurface, but try not to lose lowest layer of atmosphere
  % (important given coarse vertical resolution of IPCC models)
  dp = pfull(1)-pfull(2);
  if dp<0
   error('unexpected pressure ordering')
  end
  for j=1:length(lat)
   temp_avg(pfull>ps(j)+dp,j)=NaN;
  end


  % equal area grid
  dsin_lat = (sind(max_lat)-sind(min_lat))/(num_lat-1);
  sin_lat_grid = [sind(min_lat):dsin_lat:sind(max_lat)];
  lat_grid = asind(sin_lat_grid);

  dp = (pB-pA)/num_lev/num_lat;
  for k=0:num_lev-1
   for j=1:num_lat
    i=k*length(lat_grid)+j;
    p(i) = pA-dp/2+dp*(k*length(lat_grid) + j);
    r(i) = interp2(lat, pfull, rhum_avg, lat_grid(j), p(i));
    T(i) = interp2(lat, pfull, temp_avg, lat_grid(j), p(i));
    lat_parcel(i) = lat_grid(j);
   end
  end


  % exclude NaNs
  isf = isfinite(T)&isfinite(r);
  p = p(isf);
  r = r(isf);
  T = T(isf);
  lat_parcel = lat_parcel(isf);

  disp('divide and conquer')
  [ape, p_ref] = moist_ape_divide_conquer(T, p, r, do_nonconvective, lat_parcel, lat_grid);

  ape = ape*(pB-pA)/PARS('gravity');

